#
# spec file for package python-plette
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-plette
Version:        2.1.0
Release:        1.1
Summary:        Structured Pipfile and Pipfile.lock models
License:        ISC
URL:            https://github.com/sarugaku/plette
Source:         https://github.com/sarugaku/plette/archive/refs/tags/v%{version}.tar.gz#/plette-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 61.0.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-tomlkit
Suggests:       python-Cerberus
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Cerberus}
BuildRequires:  %{python_module invoke}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module tomlkit}
# /SECTION
%python_subpackages

%description
Structured Pipfile and Pipfile.lock models.

%prep
%autosetup -p1 -n plette-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_pipfile_load https://github.com/sarugaku/plette/issues/9
%pytest -k 'not test_pipfile_load'

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/plette
%{python_sitelib}/plette-%{version}.dist-info

%changelog
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- update to 2.1.0:
  * Fix incorrect validation for scripts with callable
* Sun Jun 30 2024 Dirk Müller <dmueller@suse.com>
- update to 2.0.2:
  This version is again a complete rewrite based
  on v0.4.4 since the approach with dataclass proved
  to be hard to convert to json while maintaining
  the public API which was used by pipenv.
* Fri Mar  1 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.0.0:
  * Rewrite the entire library using dataclasses.
  * Add more rigorous testing.
- Switch to autosetup and pyproject macros.
- No more greedy globs in %%files.
- Drop patch ignore-hashlib-case.patch, no longer required.
* Fri Jan  6 2023 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.4.4
  * Add validation for pipenv section
  * Add more tests
- Update to 0.4.3 (2022-12-13)
  Bug Fixes
  * Validate that package extras are a list
* Mon Oct 17 2022 pgajdos@suse.com
- version update to 0.4.2
  * Add logic to populate the ``default`` and ``develop`` package
    sections from the ``Pipfile`` to ``with_meta_from``.
  * Change validation schema for Requires object to allow for both
    ``python_version`` and ``python_full_version``.
  * Exclude ``pipenv`` section from ``Pipfile`` hash generation as
    this was a regression caused by named package categories.
  * Add support for named catergories.
  * Bug fix.
  * Drop Python2 support.
* Mon Mar 16 2020 Marketa Calabkova <mcalabkova@suse.com>
- Upgrade to version 0.2.3
  * Show the error details in ValidationError.
  * Ensure the data to be validated is converted to python dict.
* Tue Jul 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip test test_pipfile_load as it fails with new tomlkit
* Fri Mar  1 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.2.2
